<!--
***
*** To avoid retyping too much info. Do a search and replace for the following:
*** um-common-uma-client, eoepca-uma
-->
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
![Build][build-shield]

<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/EOEPCA/um-common-uma-client">
  </a>

  <h3 align="center">EOEPCA-UMA</h3>

  <p align="center">
    UMA Client Python Library developed by the EOEPCA User Management Team
    <br />
    <a href="https://github.com/EOEPCA/um-common-uma-client/issues">Report Bug</a>
    ·
    <a href="https://github.com/EOEPCA/um-common-uma-client/issues">Request Feature</a>
  </p>
</p>

## Table of Contents

- [Setup this template!](#setup-this-template)
- [Table of Contents](#table-of-contents)
- [About The Project](#about-the-project)
  - [Built With](#built-with)
- [Getting Started](#getting-started)
  - [Prerequisites](#prerequisites)
  - [Installation](#installation)
  - [Testing](#testing)
- [Documentation & Usage](#documentation--usage)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)
- [Acknowledgements](#acknowledgements)

## About The Project

### Built With

- [Python](https://www.python.org//)
- [PyTest](https://docs.pytest.org)
- [YAML](https://yaml.org/)
- [Travis CI](https://travis-ci.com/)

## Getting Started

To get a local copy up and running follow these simple steps.

### Prerequisites

This is an example of how to list things you need to use the software and how to install them.

- [Python 3](https://www.python.org//)
- [Pip](https://pip.pypa.io/en/stable/)

### Installation

Just download the library using pip

```sh
pip install eoepca-uma
```

### Testing

```sh
pytest eoepca-uma/tests
```

## Documentation & Usage

The component documentation can be found at https://eoepca.github.io/um-common-uma-client/.

## Roadmap

See the [open issues](https://github.com/EOEPCA/um-common-uma-client/issues) for a list of proposed features (and known issues).

## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## License

Distributed under the Apache-2.0 License. See `LICENSE` for more information.

## Contact

[EOEPCA mailbox](eoepca.systemteam@telespazio.com)

Project Link: [https://github.com/EOEPCA/um-common-uma-client](https://github.com/EOEPCA/um-common-uma-client)

## Acknowledgements

- README.md is based on [this template](https://github.com/othneildrew/Best-README-Template) by [Othneil Drew](https://github.com/othneildrew).


[contributors-shield]: https://img.shields.io/github/contributors/EOEPCA/um-common-uma-client.svg?style=flat-square
[contributors-url]: https://github.com/EOEPCA/um-common-uma-client/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/EOEPCA/um-common-uma-client.svg?style=flat-square
[forks-url]: https://github.com/EOEPCA/um-common-uma-client/network/members
[stars-shield]: https://img.shields.io/github/stars/EOEPCA/um-common-uma-client.svg?style=flat-square
[stars-url]: https://github.com/EOEPCA/um-common-uma-client/stargazers
[issues-shield]: https://img.shields.io/github/issues/EOEPCA/um-common-uma-client.svg?style=flat-square
[issues-url]: https://github.com/EOEPCA/um-common-uma-client/issues
[license-shield]: https://img.shields.io/github/license/EOEPCA/um-common-uma-client.svg?style=flat-square
[license-url]: https://github.com/EOEPCA/um-common-uma-client/blob/master/LICENSE
[build-shield]: https://www.travis-ci.com/EOEPCA/um-common-uma-client.svg?branch=master
